# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.list_items_in_path_output import ListItemsInPathOutput  # noqa: E501
from akeyless.rest import ApiException

class TestListItemsInPathOutput(unittest.TestCase):
    """ListItemsInPathOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListItemsInPathOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.list_items_in_path_output.ListItemsInPathOutput()  # noqa: E501
        if include_optional :
            return ListItemsInPathOutput(
                folders = [
                    '0'
                    ], 
                items = [
                    akeyless.models.item_describes_any_item_in_akeyless/.Item describes any item in AKEYLESS.(
                        auto_rotate = True, 
                        cert_issuer_signer_key_name = '0', 
                        certificate_issue_details = akeyless.models.certificate_issue_info_defines_certificate_issuer_info/.CertificateIssueInfo defines Certificate Issuer info.(
                            cert_issuer_type = '0', 
                            max_ttl = 56, 
                            pki_cert_issuer_details = akeyless.models.pki_certificate_issue_details_defines_pki_certificate_details/.PKICertificateIssueDetails defines PKI certificate details.(
                                allow_any_name = True, 
                                allow_subdomains = True, 
                                allowed_domains_list = [
                                    '0'
                                    ], 
                                allowed_uri_sans = [
                                    '0'
                                    ], 
                                client_flag = True, 
                                code_signing_flag = True, 
                                country = [
                                    '0'
                                    ], 
                                enforce_hostnames = True, 
                                key_bits = 56, 
                                key_type = '0', 
                                key_usage_list = [
                                    '0'
                                    ], 
                                locality = [
                                    '0'
                                    ], 
                                not_before_duration = 56, 
                                organization_list = [
                                    '0'
                                    ], 
                                organization_unit_list = [
                                    '0'
                                    ], 
                                postal_code = [
                                    '0'
                                    ], 
                                province = [
                                    '0'
                                    ], 
                                require_cn = True, 
                                server_flag = True, 
                                street_address = [
                                    '0'
                                    ], ), 
                            ssh_cert_issuer_details = akeyless.models.ssh_certificate_issue_details_defines_ssh_certificate_details/.SSHCertificateIssueDetails defines SSH certificate details.(
                                allowed_domains = [
                                    '0'
                                    ], 
                                allowed_user_key_lengths = {
                                    'key' : 56
                                    }, 
                                allowed_users = [
                                    '0'
                                    ], 
                                cert_type = 56, 
                                critical_options = {
                                    'key' : '0'
                                    }, 
                                extensions = {
                                    'key' : '0'
                                    }, 
                                principals = [
                                    '0'
                                    ], 
                                static_key_id = '0', ), ), 
                        certificates = '0', 
                        client_permissions = [
                            '0'
                            ], 
                        deletion_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_enabled = True, 
                        item_general_info = akeyless.models.item_general_info_defines_item_general_info/.ItemGeneralInfo defines item general info.(
                            cert_issue_details = akeyless.models.certificate_issue_info_defines_certificate_issuer_info/.CertificateIssueInfo defines Certificate Issuer info.(
                                cert_issuer_type = '0', 
                                max_ttl = 56, ), 
                            dynamic_secret_producer_details = akeyless.models.dynamic_secret_producer_info.DynamicSecretProducerInfo(
                                producer_status = '0', 
                                producer_type = '0', ), ), 
                        item_metadata = '0', 
                        item_name = '0', 
                        item_size = 56, 
                        item_state = '0', 
                        item_tags = [
                            '0'
                            ], 
                        item_type = '0', 
                        item_versions = [
                            akeyless.models.item_version_describes_an_item_version_in_akeyless/.ItemVersion describes an item version in AKEYLESS.(
                                creation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                deletion_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                item_version_state = '0', 
                                protection_key_name = '0', 
                                version = 56, 
                                with_customer_fragment = True, )
                            ], 
                        last_version = 56, 
                        next_rotation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        producer_status = '0', 
                        protection_key_name = '0', 
                        public_value = '0', 
                        rotation_interval = 56, 
                        with_customer_fragment = True, )
                    ], 
                next_page = '0'
            )
        else :
            return ListItemsInPathOutput(
        )

    def testListItemsInPathOutput(self):
        """Test ListItemsInPathOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class SecureRemoteAccess(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'allow_port_forwarding': 'bool',
        'allow_providing_external_username': 'bool',
        'bastion_api': 'str',
        'bastion_issuer': 'str',
        'bastion_issuer_id': 'int',
        'bastion_ssh': 'str',
        'category': 'str',
        'dashboard_url': 'str',
        'db_name': 'str',
        'domain': 'str',
        'enable': 'bool',
        'endpoint': 'str',
        'host': 'list[str]',
        'is_cli': 'bool',
        'is_web': 'bool',
        'isolated': 'bool',
        'native': 'bool',
        'rdp_user': 'str',
        'region': 'str',
        'schema': 'str',
        'ssh_password': 'bool',
        'ssh_private_key': 'bool',
        'ssh_user': 'str',
        'url': 'str',
        'use_internal_bastion': 'bool',
        'web_proxy': 'bool'
    }

    attribute_map = {
        'account_id': 'account_id',
        'allow_port_forwarding': 'allow_port_forwarding',
        'allow_providing_external_username': 'allow_providing_external_username',
        'bastion_api': 'bastion_api',
        'bastion_issuer': 'bastion_issuer',
        'bastion_issuer_id': 'bastion_issuer_id',
        'bastion_ssh': 'bastion_ssh',
        'category': 'category',
        'dashboard_url': 'dashboard_url',
        'db_name': 'db_name',
        'domain': 'domain',
        'enable': 'enable',
        'endpoint': 'endpoint',
        'host': 'host',
        'is_cli': 'is_cli',
        'is_web': 'is_web',
        'isolated': 'isolated',
        'native': 'native',
        'rdp_user': 'rdp_user',
        'region': 'region',
        'schema': 'schema',
        'ssh_password': 'ssh_password',
        'ssh_private_key': 'ssh_private_key',
        'ssh_user': 'ssh_user',
        'url': 'url',
        'use_internal_bastion': 'use_internal_bastion',
        'web_proxy': 'web_proxy'
    }

    def __init__(self, account_id=None, allow_port_forwarding=None, allow_providing_external_username=None, bastion_api=None, bastion_issuer=None, bastion_issuer_id=None, bastion_ssh=None, category=None, dashboard_url=None, db_name=None, domain=None, enable=None, endpoint=None, host=None, is_cli=None, is_web=None, isolated=None, native=None, rdp_user=None, region=None, schema=None, ssh_password=None, ssh_private_key=None, ssh_user=None, url=None, use_internal_bastion=None, web_proxy=None, local_vars_configuration=None):  # noqa: E501
        """SecureRemoteAccess - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._allow_port_forwarding = None
        self._allow_providing_external_username = None
        self._bastion_api = None
        self._bastion_issuer = None
        self._bastion_issuer_id = None
        self._bastion_ssh = None
        self._category = None
        self._dashboard_url = None
        self._db_name = None
        self._domain = None
        self._enable = None
        self._endpoint = None
        self._host = None
        self._is_cli = None
        self._is_web = None
        self._isolated = None
        self._native = None
        self._rdp_user = None
        self._region = None
        self._schema = None
        self._ssh_password = None
        self._ssh_private_key = None
        self._ssh_user = None
        self._url = None
        self._use_internal_bastion = None
        self._web_proxy = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if allow_port_forwarding is not None:
            self.allow_port_forwarding = allow_port_forwarding
        if allow_providing_external_username is not None:
            self.allow_providing_external_username = allow_providing_external_username
        if bastion_api is not None:
            self.bastion_api = bastion_api
        if bastion_issuer is not None:
            self.bastion_issuer = bastion_issuer
        if bastion_issuer_id is not None:
            self.bastion_issuer_id = bastion_issuer_id
        if bastion_ssh is not None:
            self.bastion_ssh = bastion_ssh
        if category is not None:
            self.category = category
        if dashboard_url is not None:
            self.dashboard_url = dashboard_url
        if db_name is not None:
            self.db_name = db_name
        if domain is not None:
            self.domain = domain
        if enable is not None:
            self.enable = enable
        if endpoint is not None:
            self.endpoint = endpoint
        if host is not None:
            self.host = host
        if is_cli is not None:
            self.is_cli = is_cli
        if is_web is not None:
            self.is_web = is_web
        if isolated is not None:
            self.isolated = isolated
        if native is not None:
            self.native = native
        if rdp_user is not None:
            self.rdp_user = rdp_user
        if region is not None:
            self.region = region
        if schema is not None:
            self.schema = schema
        if ssh_password is not None:
            self.ssh_password = ssh_password
        if ssh_private_key is not None:
            self.ssh_private_key = ssh_private_key
        if ssh_user is not None:
            self.ssh_user = ssh_user
        if url is not None:
            self.url = url
        if use_internal_bastion is not None:
            self.use_internal_bastion = use_internal_bastion
        if web_proxy is not None:
            self.web_proxy = web_proxy

    @property
    def account_id(self):
        """Gets the account_id of this SecureRemoteAccess.  # noqa: E501


        :return: The account_id of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this SecureRemoteAccess.


        :param account_id: The account_id of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def allow_port_forwarding(self):
        """Gets the allow_port_forwarding of this SecureRemoteAccess.  # noqa: E501


        :return: The allow_port_forwarding of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._allow_port_forwarding

    @allow_port_forwarding.setter
    def allow_port_forwarding(self, allow_port_forwarding):
        """Sets the allow_port_forwarding of this SecureRemoteAccess.


        :param allow_port_forwarding: The allow_port_forwarding of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._allow_port_forwarding = allow_port_forwarding

    @property
    def allow_providing_external_username(self):
        """Gets the allow_providing_external_username of this SecureRemoteAccess.  # noqa: E501


        :return: The allow_providing_external_username of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._allow_providing_external_username

    @allow_providing_external_username.setter
    def allow_providing_external_username(self, allow_providing_external_username):
        """Sets the allow_providing_external_username of this SecureRemoteAccess.


        :param allow_providing_external_username: The allow_providing_external_username of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._allow_providing_external_username = allow_providing_external_username

    @property
    def bastion_api(self):
        """Gets the bastion_api of this SecureRemoteAccess.  # noqa: E501


        :return: The bastion_api of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._bastion_api

    @bastion_api.setter
    def bastion_api(self, bastion_api):
        """Sets the bastion_api of this SecureRemoteAccess.


        :param bastion_api: The bastion_api of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._bastion_api = bastion_api

    @property
    def bastion_issuer(self):
        """Gets the bastion_issuer of this SecureRemoteAccess.  # noqa: E501


        :return: The bastion_issuer of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._bastion_issuer

    @bastion_issuer.setter
    def bastion_issuer(self, bastion_issuer):
        """Sets the bastion_issuer of this SecureRemoteAccess.


        :param bastion_issuer: The bastion_issuer of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._bastion_issuer = bastion_issuer

    @property
    def bastion_issuer_id(self):
        """Gets the bastion_issuer_id of this SecureRemoteAccess.  # noqa: E501


        :return: The bastion_issuer_id of this SecureRemoteAccess.  # noqa: E501
        :rtype: int
        """
        return self._bastion_issuer_id

    @bastion_issuer_id.setter
    def bastion_issuer_id(self, bastion_issuer_id):
        """Sets the bastion_issuer_id of this SecureRemoteAccess.


        :param bastion_issuer_id: The bastion_issuer_id of this SecureRemoteAccess.  # noqa: E501
        :type: int
        """

        self._bastion_issuer_id = bastion_issuer_id

    @property
    def bastion_ssh(self):
        """Gets the bastion_ssh of this SecureRemoteAccess.  # noqa: E501


        :return: The bastion_ssh of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._bastion_ssh

    @bastion_ssh.setter
    def bastion_ssh(self, bastion_ssh):
        """Sets the bastion_ssh of this SecureRemoteAccess.


        :param bastion_ssh: The bastion_ssh of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._bastion_ssh = bastion_ssh

    @property
    def category(self):
        """Gets the category of this SecureRemoteAccess.  # noqa: E501


        :return: The category of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this SecureRemoteAccess.


        :param category: The category of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def dashboard_url(self):
        """Gets the dashboard_url of this SecureRemoteAccess.  # noqa: E501


        :return: The dashboard_url of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_url

    @dashboard_url.setter
    def dashboard_url(self, dashboard_url):
        """Sets the dashboard_url of this SecureRemoteAccess.


        :param dashboard_url: The dashboard_url of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._dashboard_url = dashboard_url

    @property
    def db_name(self):
        """Gets the db_name of this SecureRemoteAccess.  # noqa: E501


        :return: The db_name of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """Sets the db_name of this SecureRemoteAccess.


        :param db_name: The db_name of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._db_name = db_name

    @property
    def domain(self):
        """Gets the domain of this SecureRemoteAccess.  # noqa: E501


        :return: The domain of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this SecureRemoteAccess.


        :param domain: The domain of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def enable(self):
        """Gets the enable of this SecureRemoteAccess.  # noqa: E501


        :return: The enable of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._enable

    @enable.setter
    def enable(self, enable):
        """Sets the enable of this SecureRemoteAccess.


        :param enable: The enable of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._enable = enable

    @property
    def endpoint(self):
        """Gets the endpoint of this SecureRemoteAccess.  # noqa: E501


        :return: The endpoint of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this SecureRemoteAccess.


        :param endpoint: The endpoint of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def host(self):
        """Gets the host of this SecureRemoteAccess.  # noqa: E501


        :return: The host of this SecureRemoteAccess.  # noqa: E501
        :rtype: list[str]
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this SecureRemoteAccess.


        :param host: The host of this SecureRemoteAccess.  # noqa: E501
        :type: list[str]
        """

        self._host = host

    @property
    def is_cli(self):
        """Gets the is_cli of this SecureRemoteAccess.  # noqa: E501


        :return: The is_cli of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._is_cli

    @is_cli.setter
    def is_cli(self, is_cli):
        """Sets the is_cli of this SecureRemoteAccess.


        :param is_cli: The is_cli of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._is_cli = is_cli

    @property
    def is_web(self):
        """Gets the is_web of this SecureRemoteAccess.  # noqa: E501


        :return: The is_web of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._is_web

    @is_web.setter
    def is_web(self, is_web):
        """Sets the is_web of this SecureRemoteAccess.


        :param is_web: The is_web of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._is_web = is_web

    @property
    def isolated(self):
        """Gets the isolated of this SecureRemoteAccess.  # noqa: E501


        :return: The isolated of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._isolated

    @isolated.setter
    def isolated(self, isolated):
        """Sets the isolated of this SecureRemoteAccess.


        :param isolated: The isolated of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._isolated = isolated

    @property
    def native(self):
        """Gets the native of this SecureRemoteAccess.  # noqa: E501


        :return: The native of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._native

    @native.setter
    def native(self, native):
        """Sets the native of this SecureRemoteAccess.


        :param native: The native of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._native = native

    @property
    def rdp_user(self):
        """Gets the rdp_user of this SecureRemoteAccess.  # noqa: E501


        :return: The rdp_user of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._rdp_user

    @rdp_user.setter
    def rdp_user(self, rdp_user):
        """Sets the rdp_user of this SecureRemoteAccess.


        :param rdp_user: The rdp_user of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._rdp_user = rdp_user

    @property
    def region(self):
        """Gets the region of this SecureRemoteAccess.  # noqa: E501


        :return: The region of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this SecureRemoteAccess.


        :param region: The region of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def schema(self):
        """Gets the schema of this SecureRemoteAccess.  # noqa: E501


        :return: The schema of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this SecureRemoteAccess.


        :param schema: The schema of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._schema = schema

    @property
    def ssh_password(self):
        """Gets the ssh_password of this SecureRemoteAccess.  # noqa: E501


        :return: The ssh_password of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._ssh_password

    @ssh_password.setter
    def ssh_password(self, ssh_password):
        """Sets the ssh_password of this SecureRemoteAccess.


        :param ssh_password: The ssh_password of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._ssh_password = ssh_password

    @property
    def ssh_private_key(self):
        """Gets the ssh_private_key of this SecureRemoteAccess.  # noqa: E501


        :return: The ssh_private_key of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._ssh_private_key

    @ssh_private_key.setter
    def ssh_private_key(self, ssh_private_key):
        """Sets the ssh_private_key of this SecureRemoteAccess.


        :param ssh_private_key: The ssh_private_key of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._ssh_private_key = ssh_private_key

    @property
    def ssh_user(self):
        """Gets the ssh_user of this SecureRemoteAccess.  # noqa: E501


        :return: The ssh_user of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._ssh_user

    @ssh_user.setter
    def ssh_user(self, ssh_user):
        """Sets the ssh_user of this SecureRemoteAccess.


        :param ssh_user: The ssh_user of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._ssh_user = ssh_user

    @property
    def url(self):
        """Gets the url of this SecureRemoteAccess.  # noqa: E501


        :return: The url of this SecureRemoteAccess.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SecureRemoteAccess.


        :param url: The url of this SecureRemoteAccess.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def use_internal_bastion(self):
        """Gets the use_internal_bastion of this SecureRemoteAccess.  # noqa: E501


        :return: The use_internal_bastion of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._use_internal_bastion

    @use_internal_bastion.setter
    def use_internal_bastion(self, use_internal_bastion):
        """Sets the use_internal_bastion of this SecureRemoteAccess.


        :param use_internal_bastion: The use_internal_bastion of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._use_internal_bastion = use_internal_bastion

    @property
    def web_proxy(self):
        """Gets the web_proxy of this SecureRemoteAccess.  # noqa: E501


        :return: The web_proxy of this SecureRemoteAccess.  # noqa: E501
        :rtype: bool
        """
        return self._web_proxy

    @web_proxy.setter
    def web_proxy(self, web_proxy):
        """Sets the web_proxy of this SecureRemoteAccess.


        :param web_proxy: The web_proxy of this SecureRemoteAccess.  # noqa: E501
        :type: bool
        """

        self._web_proxy = web_proxy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecureRemoteAccess):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SecureRemoteAccess):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateSalesforceTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_private_key_data': 'str',
        'auth_flow': 'str',
        'ca_cert_data': 'str',
        'ca_cert_name': 'str',
        'client_id': 'str',
        'client_secret': 'str',
        'comment': 'str',
        'email': 'str',
        'json': 'bool',
        'keep_prev_version': 'str',
        'key': 'str',
        'name': 'str',
        'new_name': 'str',
        'password': 'str',
        'security_token': 'str',
        'tenant_url': 'str',
        'token': 'str',
        'uid_token': 'str',
        'update_version': 'bool'
    }

    attribute_map = {
        'app_private_key_data': 'app-private-key-data',
        'auth_flow': 'auth-flow',
        'ca_cert_data': 'ca-cert-data',
        'ca_cert_name': 'ca-cert-name',
        'client_id': 'client-id',
        'client_secret': 'client-secret',
        'comment': 'comment',
        'email': 'email',
        'json': 'json',
        'keep_prev_version': 'keep-prev-version',
        'key': 'key',
        'name': 'name',
        'new_name': 'new-name',
        'password': 'password',
        'security_token': 'security-token',
        'tenant_url': 'tenant-url',
        'token': 'token',
        'uid_token': 'uid-token',
        'update_version': 'update-version'
    }

    def __init__(self, app_private_key_data=None, auth_flow=None, ca_cert_data=None, ca_cert_name=None, client_id=None, client_secret=None, comment=None, email=None, json=None, keep_prev_version=None, key=None, name=None, new_name=None, password=None, security_token=None, tenant_url=None, token=None, uid_token=None, update_version=None, local_vars_configuration=None):  # noqa: E501
        """UpdateSalesforceTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._app_private_key_data = None
        self._auth_flow = None
        self._ca_cert_data = None
        self._ca_cert_name = None
        self._client_id = None
        self._client_secret = None
        self._comment = None
        self._email = None
        self._json = None
        self._keep_prev_version = None
        self._key = None
        self._name = None
        self._new_name = None
        self._password = None
        self._security_token = None
        self._tenant_url = None
        self._token = None
        self._uid_token = None
        self._update_version = None
        self.discriminator = None

        if app_private_key_data is not None:
            self.app_private_key_data = app_private_key_data
        self.auth_flow = auth_flow
        if ca_cert_data is not None:
            self.ca_cert_data = ca_cert_data
        if ca_cert_name is not None:
            self.ca_cert_name = ca_cert_name
        self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if comment is not None:
            self.comment = comment
        self.email = email
        if json is not None:
            self.json = json
        if keep_prev_version is not None:
            self.keep_prev_version = keep_prev_version
        if key is not None:
            self.key = key
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if password is not None:
            self.password = password
        if security_token is not None:
            self.security_token = security_token
        self.tenant_url = tenant_url
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if update_version is not None:
            self.update_version = update_version

    @property
    def app_private_key_data(self):
        """Gets the app_private_key_data of this UpdateSalesforceTarget.  # noqa: E501

        Base64 encoded PEM of the connected app private key (relevant for JWT auth only)  # noqa: E501

        :return: The app_private_key_data of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._app_private_key_data

    @app_private_key_data.setter
    def app_private_key_data(self, app_private_key_data):
        """Sets the app_private_key_data of this UpdateSalesforceTarget.

        Base64 encoded PEM of the connected app private key (relevant for JWT auth only)  # noqa: E501

        :param app_private_key_data: The app_private_key_data of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._app_private_key_data = app_private_key_data

    @property
    def auth_flow(self):
        """Gets the auth_flow of this UpdateSalesforceTarget.  # noqa: E501

        type of the auth flow ('jwt' / 'user-password')  # noqa: E501

        :return: The auth_flow of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._auth_flow

    @auth_flow.setter
    def auth_flow(self, auth_flow):
        """Sets the auth_flow of this UpdateSalesforceTarget.

        type of the auth flow ('jwt' / 'user-password')  # noqa: E501

        :param auth_flow: The auth_flow of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and auth_flow is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_flow`, must not be `None`")  # noqa: E501

        self._auth_flow = auth_flow

    @property
    def ca_cert_data(self):
        """Gets the ca_cert_data of this UpdateSalesforceTarget.  # noqa: E501

        Base64 encoded PEM cert to use when uploading a new key to Salesforce  # noqa: E501

        :return: The ca_cert_data of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert_data

    @ca_cert_data.setter
    def ca_cert_data(self, ca_cert_data):
        """Sets the ca_cert_data of this UpdateSalesforceTarget.

        Base64 encoded PEM cert to use when uploading a new key to Salesforce  # noqa: E501

        :param ca_cert_data: The ca_cert_data of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._ca_cert_data = ca_cert_data

    @property
    def ca_cert_name(self):
        """Gets the ca_cert_name of this UpdateSalesforceTarget.  # noqa: E501

        name of the certificate in Salesforce tenant to use when uploading new key  # noqa: E501

        :return: The ca_cert_name of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert_name

    @ca_cert_name.setter
    def ca_cert_name(self, ca_cert_name):
        """Sets the ca_cert_name of this UpdateSalesforceTarget.

        name of the certificate in Salesforce tenant to use when uploading new key  # noqa: E501

        :param ca_cert_name: The ca_cert_name of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._ca_cert_name = ca_cert_name

    @property
    def client_id(self):
        """Gets the client_id of this UpdateSalesforceTarget.  # noqa: E501

        Client ID of the oauth2 app to use for connecting to Salesforce  # noqa: E501

        :return: The client_id of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this UpdateSalesforceTarget.

        Client ID of the oauth2 app to use for connecting to Salesforce  # noqa: E501

        :param client_id: The client_id of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this UpdateSalesforceTarget.  # noqa: E501

        Client secret of the oauth2 app to use for connecting to Salesforce (required for password flow)  # noqa: E501

        :return: The client_secret of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this UpdateSalesforceTarget.

        Client secret of the oauth2 app to use for connecting to Salesforce (required for password flow)  # noqa: E501

        :param client_secret: The client_secret of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def comment(self):
        """Gets the comment of this UpdateSalesforceTarget.  # noqa: E501

        Comment about the target  # noqa: E501

        :return: The comment of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UpdateSalesforceTarget.

        Comment about the target  # noqa: E501

        :param comment: The comment of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def email(self):
        """Gets the email of this UpdateSalesforceTarget.  # noqa: E501

        The email of the user attached to the oauth2 app used for connecting to Salesforce  # noqa: E501

        :return: The email of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UpdateSalesforceTarget.

        The email of the user attached to the oauth2 app used for connecting to Salesforce  # noqa: E501

        :param email: The email of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def json(self):
        """Gets the json of this UpdateSalesforceTarget.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateSalesforceTarget.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateSalesforceTarget.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def keep_prev_version(self):
        """Gets the keep_prev_version of this UpdateSalesforceTarget.  # noqa: E501


        :return: The keep_prev_version of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._keep_prev_version

    @keep_prev_version.setter
    def keep_prev_version(self, keep_prev_version):
        """Sets the keep_prev_version of this UpdateSalesforceTarget.


        :param keep_prev_version: The keep_prev_version of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._keep_prev_version = keep_prev_version

    @property
    def key(self):
        """Gets the key of this UpdateSalesforceTarget.  # noqa: E501

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this UpdateSalesforceTarget.

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def name(self):
        """Gets the name of this UpdateSalesforceTarget.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateSalesforceTarget.

        Target name  # noqa: E501

        :param name: The name of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this UpdateSalesforceTarget.  # noqa: E501

        New target name  # noqa: E501

        :return: The new_name of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this UpdateSalesforceTarget.

        New target name  # noqa: E501

        :param new_name: The new_name of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def password(self):
        """Gets the password of this UpdateSalesforceTarget.  # noqa: E501

        The password of the user attached to the oauth2 app used for connecting to Salesforce (required for user-password flow)  # noqa: E501

        :return: The password of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateSalesforceTarget.

        The password of the user attached to the oauth2 app used for connecting to Salesforce (required for user-password flow)  # noqa: E501

        :param password: The password of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def security_token(self):
        """Gets the security_token of this UpdateSalesforceTarget.  # noqa: E501

        The security token of the user attached to the oauth2 app used for connecting to Salesforce  (required for user-password flow)  # noqa: E501

        :return: The security_token of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._security_token

    @security_token.setter
    def security_token(self, security_token):
        """Sets the security_token of this UpdateSalesforceTarget.

        The security token of the user attached to the oauth2 app used for connecting to Salesforce  (required for user-password flow)  # noqa: E501

        :param security_token: The security_token of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._security_token = security_token

    @property
    def tenant_url(self):
        """Gets the tenant_url of this UpdateSalesforceTarget.  # noqa: E501

        Url of the Salesforce tenant  # noqa: E501

        :return: The tenant_url of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._tenant_url

    @tenant_url.setter
    def tenant_url(self, tenant_url):
        """Sets the tenant_url of this UpdateSalesforceTarget.

        Url of the Salesforce tenant  # noqa: E501

        :param tenant_url: The tenant_url of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tenant_url is None:  # noqa: E501
            raise ValueError("Invalid value for `tenant_url`, must not be `None`")  # noqa: E501

        self._tenant_url = tenant_url

    @property
    def token(self):
        """Gets the token of this UpdateSalesforceTarget.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateSalesforceTarget.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateSalesforceTarget.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateSalesforceTarget.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateSalesforceTarget.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def update_version(self):
        """Gets the update_version of this UpdateSalesforceTarget.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The update_version of this UpdateSalesforceTarget.  # noqa: E501
        :rtype: bool
        """
        return self._update_version

    @update_version.setter
    def update_version(self, update_version):
        """Sets the update_version of this UpdateSalesforceTarget.

        Deprecated  # noqa: E501

        :param update_version: The update_version of this UpdateSalesforceTarget.  # noqa: E501
        :type: bool
        """

        self._update_version = update_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSalesforceTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateSalesforceTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.certificate_issue_info import CertificateIssueInfo  # noqa: E501
from akeyless.rest import ApiException

class TestCertificateIssueInfo(unittest.TestCase):
    """CertificateIssueInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CertificateIssueInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.certificate_issue_info.CertificateIssueInfo()  # noqa: E501
        if include_optional :
            return CertificateIssueInfo(
                cert_issuer_type = '0', 
                max_ttl = 56, 
                pki_cert_issuer_details = akeyless.models.pki_certificate_issue_details_defines_pki_certificate_details/.PKICertificateIssueDetails defines PKI certificate details.(
                    allow_any_name = True, 
                    allow_subdomains = True, 
                    allowed_domains_list = [
                        '0'
                        ], 
                    allowed_uri_sans = [
                        '0'
                        ], 
                    client_flag = True, 
                    code_signing_flag = True, 
                    country = [
                        '0'
                        ], 
                    enforce_hostnames = True, 
                    key_bits = 56, 
                    key_type = '0', 
                    key_usage_list = [
                        '0'
                        ], 
                    locality = [
                        '0'
                        ], 
                    not_before_duration = 56, 
                    organization_list = [
                        '0'
                        ], 
                    organization_unit_list = [
                        '0'
                        ], 
                    postal_code = [
                        '0'
                        ], 
                    province = [
                        '0'
                        ], 
                    require_cn = True, 
                    server_flag = True, 
                    street_address = [
                        '0'
                        ], ), 
                ssh_cert_issuer_details = akeyless.models.ssh_certificate_issue_details_defines_ssh_certificate_details/.SSHCertificateIssueDetails defines SSH certificate details.(
                    allowed_domains = [
                        '0'
                        ], 
                    allowed_user_key_lengths = {
                        'key' : 56
                        }, 
                    allowed_users = [
                        '0'
                        ], 
                    cert_type = 56, 
                    critical_options = {
                        'key' : '0'
                        }, 
                    extensions = {
                        'key' : '0'
                        }, 
                    principals = [
                        '0'
                        ], 
                    static_key_id = '0', )
            )
        else :
            return CertificateIssueInfo(
        )

    def testCertificateIssueInfo(self):
        """Test CertificateIssueInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class RegexpTokenizerInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alphabet': 'str',
        'decoding_template': 'str',
        'encoding_template': 'str',
        'pattern': 'str'
    }

    attribute_map = {
        'alphabet': 'alphabet',
        'decoding_template': 'decoding_template',
        'encoding_template': 'encoding_template',
        'pattern': 'pattern'
    }

    def __init__(self, alphabet=None, decoding_template=None, encoding_template=None, pattern=None, local_vars_configuration=None):  # noqa: E501
        """RegexpTokenizerInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alphabet = None
        self._decoding_template = None
        self._encoding_template = None
        self._pattern = None
        self.discriminator = None

        if alphabet is not None:
            self.alphabet = alphabet
        if decoding_template is not None:
            self.decoding_template = decoding_template
        if encoding_template is not None:
            self.encoding_template = encoding_template
        if pattern is not None:
            self.pattern = pattern

    @property
    def alphabet(self):
        """Gets the alphabet of this RegexpTokenizerInfo.  # noqa: E501

        The Alphabet used for the tokenization  # noqa: E501

        :return: The alphabet of this RegexpTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._alphabet

    @alphabet.setter
    def alphabet(self, alphabet):
        """Sets the alphabet of this RegexpTokenizerInfo.

        The Alphabet used for the tokenization  # noqa: E501

        :param alphabet: The alphabet of this RegexpTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._alphabet = alphabet

    @property
    def decoding_template(self):
        """Gets the decoding_template of this RegexpTokenizerInfo.  # noqa: E501

        Transformation to perform on the decrypted data  # noqa: E501

        :return: The decoding_template of this RegexpTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._decoding_template

    @decoding_template.setter
    def decoding_template(self, decoding_template):
        """Sets the decoding_template of this RegexpTokenizerInfo.

        Transformation to perform on the decrypted data  # noqa: E501

        :param decoding_template: The decoding_template of this RegexpTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._decoding_template = decoding_template

    @property
    def encoding_template(self):
        """Gets the encoding_template of this RegexpTokenizerInfo.  # noqa: E501

        Transformation to perform on the encrypted data, if the required output template doesn't match the input string The output Should still be valid for the Pattern, otherwise the secret would be able to be decrypted.  # noqa: E501

        :return: The encoding_template of this RegexpTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._encoding_template

    @encoding_template.setter
    def encoding_template(self, encoding_template):
        """Sets the encoding_template of this RegexpTokenizerInfo.

        Transformation to perform on the encrypted data, if the required output template doesn't match the input string The output Should still be valid for the Pattern, otherwise the secret would be able to be decrypted.  # noqa: E501

        :param encoding_template: The encoding_template of this RegexpTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._encoding_template = encoding_template

    @property
    def pattern(self):
        """Gets the pattern of this RegexpTokenizerInfo.  # noqa: E501

        Regexp pattern to extract and deposit the text/encdata  # noqa: E501

        :return: The pattern of this RegexpTokenizerInfo.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this RegexpTokenizerInfo.

        Regexp pattern to extract and deposit the text/encdata  # noqa: E501

        :param pattern: The pattern of this RegexpTokenizerInfo.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegexpTokenizerInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RegexpTokenizerInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class DeleteTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'force_deletion': 'bool',
        'json': 'bool',
        'name': 'str',
        'target_version': 'int',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'force_deletion': 'force-deletion',
        'json': 'json',
        'name': 'name',
        'target_version': 'target-version',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, force_deletion=False, json=None, name=None, target_version=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """DeleteTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._force_deletion = None
        self._json = None
        self._name = None
        self._target_version = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        if force_deletion is not None:
            self.force_deletion = force_deletion
        if json is not None:
            self.json = json
        self.name = name
        if target_version is not None:
            self.target_version = target_version
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def force_deletion(self):
        """Gets the force_deletion of this DeleteTarget.  # noqa: E501

        Enforce deletion  # noqa: E501

        :return: The force_deletion of this DeleteTarget.  # noqa: E501
        :rtype: bool
        """
        return self._force_deletion

    @force_deletion.setter
    def force_deletion(self, force_deletion):
        """Sets the force_deletion of this DeleteTarget.

        Enforce deletion  # noqa: E501

        :param force_deletion: The force_deletion of this DeleteTarget.  # noqa: E501
        :type: bool
        """

        self._force_deletion = force_deletion

    @property
    def json(self):
        """Gets the json of this DeleteTarget.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this DeleteTarget.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this DeleteTarget.

        Set output format to JSON  # noqa: E501

        :param json: The json of this DeleteTarget.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this DeleteTarget.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this DeleteTarget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeleteTarget.

        Target name  # noqa: E501

        :param name: The name of this DeleteTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def target_version(self):
        """Gets the target_version of this DeleteTarget.  # noqa: E501

        Target version  # noqa: E501

        :return: The target_version of this DeleteTarget.  # noqa: E501
        :rtype: int
        """
        return self._target_version

    @target_version.setter
    def target_version(self, target_version):
        """Sets the target_version of this DeleteTarget.

        Target version  # noqa: E501

        :param target_version: The target_version of this DeleteTarget.  # noqa: E501
        :type: int
        """

        self._target_version = target_version

    @property
    def token(self):
        """Gets the token of this DeleteTarget.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this DeleteTarget.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this DeleteTarget.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this DeleteTarget.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this DeleteTarget.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this DeleteTarget.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this DeleteTarget.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this DeleteTarget.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeleteTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class TargetObjectAssociation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'assoc_id': 'str',
        'attributes': 'dict(str, str)',
        'object_id': 'str',
        'object_name': 'str',
        'object_type': 'str',
        'target_name': 'str'
    }

    attribute_map = {
        'assoc_id': 'assoc_id',
        'attributes': 'attributes',
        'object_id': 'object_id',
        'object_name': 'object_name',
        'object_type': 'object_type',
        'target_name': 'target_name'
    }

    def __init__(self, assoc_id=None, attributes=None, object_id=None, object_name=None, object_type=None, target_name=None, local_vars_configuration=None):  # noqa: E501
        """TargetObjectAssociation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._assoc_id = None
        self._attributes = None
        self._object_id = None
        self._object_name = None
        self._object_type = None
        self._target_name = None
        self.discriminator = None

        if assoc_id is not None:
            self.assoc_id = assoc_id
        if attributes is not None:
            self.attributes = attributes
        if object_id is not None:
            self.object_id = object_id
        if object_name is not None:
            self.object_name = object_name
        if object_type is not None:
            self.object_type = object_type
        if target_name is not None:
            self.target_name = target_name

    @property
    def assoc_id(self):
        """Gets the assoc_id of this TargetObjectAssociation.  # noqa: E501


        :return: The assoc_id of this TargetObjectAssociation.  # noqa: E501
        :rtype: str
        """
        return self._assoc_id

    @assoc_id.setter
    def assoc_id(self, assoc_id):
        """Sets the assoc_id of this TargetObjectAssociation.


        :param assoc_id: The assoc_id of this TargetObjectAssociation.  # noqa: E501
        :type: str
        """

        self._assoc_id = assoc_id

    @property
    def attributes(self):
        """Gets the attributes of this TargetObjectAssociation.  # noqa: E501


        :return: The attributes of this TargetObjectAssociation.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this TargetObjectAssociation.


        :param attributes: The attributes of this TargetObjectAssociation.  # noqa: E501
        :type: dict(str, str)
        """

        self._attributes = attributes

    @property
    def object_id(self):
        """Gets the object_id of this TargetObjectAssociation.  # noqa: E501


        :return: The object_id of this TargetObjectAssociation.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this TargetObjectAssociation.


        :param object_id: The object_id of this TargetObjectAssociation.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def object_name(self):
        """Gets the object_name of this TargetObjectAssociation.  # noqa: E501


        :return: The object_name of this TargetObjectAssociation.  # noqa: E501
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """Sets the object_name of this TargetObjectAssociation.


        :param object_name: The object_name of this TargetObjectAssociation.  # noqa: E501
        :type: str
        """

        self._object_name = object_name

    @property
    def object_type(self):
        """Gets the object_type of this TargetObjectAssociation.  # noqa: E501


        :return: The object_type of this TargetObjectAssociation.  # noqa: E501
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this TargetObjectAssociation.


        :param object_type: The object_type of this TargetObjectAssociation.  # noqa: E501
        :type: str
        """

        self._object_type = object_type

    @property
    def target_name(self):
        """Gets the target_name of this TargetObjectAssociation.  # noqa: E501


        :return: The target_name of this TargetObjectAssociation.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this TargetObjectAssociation.


        :param target_name: The target_name of this TargetObjectAssociation.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TargetObjectAssociation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TargetObjectAssociation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.certificate_chain_info import CertificateChainInfo  # noqa: E501
from akeyless.rest import ApiException

class TestCertificateChainInfo(unittest.TestCase):
    """CertificateChainInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CertificateChainInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.certificate_chain_info.CertificateChainInfo()  # noqa: E501
        if include_optional :
            return CertificateChainInfo(
                certificate_chain = [
                    akeyless.models.certificate_info.CertificateInfo(
                        ext_key_usage = [
                            56
                            ], 
                        key_usage = 56, 
                        dns_names = [
                            '0'
                            ], 
                        email_addresses = [
                            '0'
                            ], 
                        extensions = [
                            akeyless.models.extension.Extension(
                                critical = True, 
                                name = '0', 
                                value = '0', )
                            ], 
                        ip_addresses = [
                            '0'
                            ], 
                        is_ca = True, 
                        issuer = akeyless.models.name.Name(
                            country = [
                                '0'
                                ], 
                            extra_names = [
                                akeyless.models.attribute_type_and_value.AttributeTypeAndValue(
                                    type = [
                                        56
                                        ], 
                                    value = akeyless.models.value.Value(), )
                                ], 
                            locality = [
                                '0'
                                ], 
                            names = [
                                akeyless.models.attribute_type_and_value.AttributeTypeAndValue(
                                    type = [
                                        56
                                        ], 
                                    value = akeyless.models.value.Value(), )
                                ], 
                            serial_number = '0', 
                            street_address = [
                                '0'
                                ], ), 
                        issuing_certificate_url = [
                            '0'
                            ], 
                        key_size = 56, 
                        not_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        not_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ocsp_server = [
                            '0'
                            ], 
                        public_key_algorithm_name = '0', 
                        serial_number = '0', 
                        sha_1_fingerprint = '0', 
                        sha_256_fingerprint = '0', 
                        signature = '0', 
                        signature_algorithm_name = '0', 
                        subject = akeyless.models.name.Name(
                            serial_number = '0', ), 
                        subject_public_key = '0', 
                        uris = [
                            '0'
                            ], 
                        version = 56, )
                    ], 
                certificate_pem = '0', 
                expiration_events = [
                    akeyless.models.certificate_expiration_event.CertificateExpirationEvent(
                        seconds_before = 56, )
                    ]
            )
        else :
            return CertificateChainInfo(
        )

    def testCertificateChainInfo(self):
        """Test CertificateChainInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import akeyless
from akeyless.api.v2_api import V2Api  # noqa: E501
from akeyless.rest import ApiException


class TestV2Api(unittest.TestCase):
    """V2Api unit test stubs"""

    def setUp(self):
        self.api = akeyless.api.v2_api.V2Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_assoc_role_auth_method(self):
        """Test case for assoc_role_auth_method

        """
        pass

    def test_auth(self):
        """Test case for auth

        """
        pass

    def test_configure(self):
        """Test case for configure

        """
        pass

    def test_create_auth_method(self):
        """Test case for create_auth_method

        """
        pass

    def test_create_auth_method_awsiam(self):
        """Test case for create_auth_method_awsiam

        """
        pass

    def test_create_auth_method_azure_ad(self):
        """Test case for create_auth_method_azure_ad

        """
        pass

    def test_create_auth_method_huawei(self):
        """Test case for create_auth_method_huawei

        """
        pass

    def test_create_auth_method_o_auth2(self):
        """Test case for create_auth_method_o_auth2

        """
        pass

    def test_create_auth_method_saml(self):
        """Test case for create_auth_method_saml

        """
        pass

    def test_create_auth_method_universal_identity(self):
        """Test case for create_auth_method_universal_identity

        """
        pass

    def test_create_dynamic_secret(self):
        """Test case for create_dynamic_secret

        """
        pass

    def test_create_key(self):
        """Test case for create_key

        """
        pass

    def test_create_pki_cert_issuer(self):
        """Test case for create_pki_cert_issuer

        """
        pass

    def test_create_role(self):
        """Test case for create_role

        """
        pass

    def test_create_secret(self):
        """Test case for create_secret

        """
        pass

    def test_create_ssh_cert_issuer(self):
        """Test case for create_ssh_cert_issuer

        """
        pass

    def test_decrypt(self):
        """Test case for decrypt

        """
        pass

    def test_decrypt_pkcs1(self):
        """Test case for decrypt_pkcs1

        """
        pass

    def test_delete_auth_method(self):
        """Test case for delete_auth_method

        """
        pass

    def test_delete_auth_methods(self):
        """Test case for delete_auth_methods

        """
        pass

    def test_delete_item(self):
        """Test case for delete_item

        """
        pass

    def test_delete_items(self):
        """Test case for delete_items

        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        """
        pass

    def test_delete_role_association(self):
        """Test case for delete_role_association

        """
        pass

    def test_delete_role_rule(self):
        """Test case for delete_role_rule

        """
        pass

    def test_delete_roles(self):
        """Test case for delete_roles

        """
        pass

    def test_describe_item(self):
        """Test case for describe_item

        """
        pass

    def test_encrypt(self):
        """Test case for encrypt

        """
        pass

    def test_encrypt_pkcs1(self):
        """Test case for encrypt_pkcs1

        """
        pass

    def test_get_auth_method(self):
        """Test case for get_auth_method

        """
        pass

    def test_get_dynamic_secret_value(self):
        """Test case for get_dynamic_secret_value

        """
        pass

    def test_get_role(self):
        """Test case for get_role

        """
        pass

    def test_get_rsa_public(self):
        """Test case for get_rsa_public

        """
        pass

    def test_get_secret_value(self):
        """Test case for get_secret_value

        """
        pass

    def test_get_ssh_certificate(self):
        """Test case for get_ssh_certificate

        """
        pass

    def test_list_auth_methods(self):
        """Test case for list_auth_methods

        """
        pass

    def test_list_items(self):
        """Test case for list_items

        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        """
        pass

    def test_move_objects(self):
        """Test case for move_objects

        """
        pass

    def test_refresh_key(self):
        """Test case for refresh_key

        """
        pass

    def test_reverse_rbac(self):
        """Test case for reverse_rbac

        """
        pass

    def test_rollback_secret(self):
        """Test case for rollback_secret

        """
        pass

    def test_rotate_key(self):
        """Test case for rotate_key

        """
        pass

    def test_set_item_state(self):
        """Test case for set_item_state

        """
        pass

    def test_set_role_rule(self):
        """Test case for set_role_rule

        """
        pass

    def test_sign_pkcs1(self):
        """Test case for sign_pkcs1

        """
        pass

    def test_static_creds_auth(self):
        """Test case for static_creds_auth

        """
        pass

    def test_uid_create_child_token(self):
        """Test case for uid_create_child_token

        """
        pass

    def test_uid_generate_token(self):
        """Test case for uid_generate_token

        """
        pass

    def test_uid_list_children(self):
        """Test case for uid_list_children

        """
        pass

    def test_uid_revoke_token(self):
        """Test case for uid_revoke_token

        """
        pass

    def test_uid_rotate_token(self):
        """Test case for uid_rotate_token

        """
        pass

    def test_update_item(self):
        """Test case for update_item

        """
        pass

    def test_update_role(self):
        """Test case for update_role

        """
        pass

    def test_update_secret_val(self):
        """Test case for update_secret_val

        """
        pass

    def test_upload_rsa(self):
        """Test case for upload_rsa

        """
        pass

    def test_verify_pkcs1(self):
        """Test case for verify_pkcs1

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class SignPKICertWithClassicKey(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'common_name': 'str',
        'country': 'str',
        'display_id': 'str',
        'dns_names': 'str',
        'json': 'bool',
        'key_usage': 'str',
        'locality': 'str',
        'organizational_units': 'str',
        'organizations': 'str',
        'postal_code': 'str',
        'province': 'str',
        'public_key_pem_data': 'str',
        'signing_method': 'str',
        'street_address': 'str',
        'token': 'str',
        'ttl': 'int',
        'uid_token': 'str',
        'uri_sans': 'str',
        'version': 'int'
    }

    attribute_map = {
        'common_name': 'common-name',
        'country': 'country',
        'display_id': 'display-id',
        'dns_names': 'dns-names',
        'json': 'json',
        'key_usage': 'key-usage',
        'locality': 'locality',
        'organizational_units': 'organizational-units',
        'organizations': 'organizations',
        'postal_code': 'postal-code',
        'province': 'province',
        'public_key_pem_data': 'public-key-pem-data',
        'signing_method': 'signing-method',
        'street_address': 'street-address',
        'token': 'token',
        'ttl': 'ttl',
        'uid_token': 'uid-token',
        'uri_sans': 'uri-sans',
        'version': 'version'
    }

    def __init__(self, common_name=None, country=None, display_id=None, dns_names=None, json=None, key_usage='DigitalSignature,KeyAgreement,KeyEncipherment', locality=None, organizational_units=None, organizations=None, postal_code=None, province=None, public_key_pem_data=None, signing_method=None, street_address=None, token=None, ttl=None, uid_token=None, uri_sans=None, version=None, local_vars_configuration=None):  # noqa: E501
        """SignPKICertWithClassicKey - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._common_name = None
        self._country = None
        self._display_id = None
        self._dns_names = None
        self._json = None
        self._key_usage = None
        self._locality = None
        self._organizational_units = None
        self._organizations = None
        self._postal_code = None
        self._province = None
        self._public_key_pem_data = None
        self._signing_method = None
        self._street_address = None
        self._token = None
        self._ttl = None
        self._uid_token = None
        self._uri_sans = None
        self._version = None
        self.discriminator = None

        if common_name is not None:
            self.common_name = common_name
        if country is not None:
            self.country = country
        self.display_id = display_id
        if dns_names is not None:
            self.dns_names = dns_names
        if json is not None:
            self.json = json
        if key_usage is not None:
            self.key_usage = key_usage
        if locality is not None:
            self.locality = locality
        if organizational_units is not None:
            self.organizational_units = organizational_units
        if organizations is not None:
            self.organizations = organizations
        if postal_code is not None:
            self.postal_code = postal_code
        if province is not None:
            self.province = province
        if public_key_pem_data is not None:
            self.public_key_pem_data = public_key_pem_data
        self.signing_method = signing_method
        if street_address is not None:
            self.street_address = street_address
        if token is not None:
            self.token = token
        self.ttl = ttl
        if uid_token is not None:
            self.uid_token = uid_token
        if uri_sans is not None:
            self.uri_sans = uri_sans
        self.version = version

    @property
    def common_name(self):
        """Gets the common_name of this SignPKICertWithClassicKey.  # noqa: E501

        The common name to be included in the PKI certificate  # noqa: E501

        :return: The common_name of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._common_name

    @common_name.setter
    def common_name(self, common_name):
        """Sets the common_name of this SignPKICertWithClassicKey.

        The common name to be included in the PKI certificate  # noqa: E501

        :param common_name: The common_name of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._common_name = common_name

    @property
    def country(self):
        """Gets the country of this SignPKICertWithClassicKey.  # noqa: E501

        A comma-separated list of the country that will be set in the issued certificate  # noqa: E501

        :return: The country of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this SignPKICertWithClassicKey.

        A comma-separated list of the country that will be set in the issued certificate  # noqa: E501

        :param country: The country of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def display_id(self):
        """Gets the display_id of this SignPKICertWithClassicKey.  # noqa: E501

        The name of the key to use in the sign PKI Cert process  # noqa: E501

        :return: The display_id of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._display_id

    @display_id.setter
    def display_id(self, display_id):
        """Sets the display_id of this SignPKICertWithClassicKey.

        The name of the key to use in the sign PKI Cert process  # noqa: E501

        :param display_id: The display_id of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and display_id is None:  # noqa: E501
            raise ValueError("Invalid value for `display_id`, must not be `None`")  # noqa: E501

        self._display_id = display_id

    @property
    def dns_names(self):
        """Gets the dns_names of this SignPKICertWithClassicKey.  # noqa: E501

        DNS Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :return: The dns_names of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._dns_names

    @dns_names.setter
    def dns_names(self, dns_names):
        """Sets the dns_names of this SignPKICertWithClassicKey.

        DNS Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :param dns_names: The dns_names of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._dns_names = dns_names

    @property
    def json(self):
        """Gets the json of this SignPKICertWithClassicKey.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this SignPKICertWithClassicKey.

        Set output format to JSON  # noqa: E501

        :param json: The json of this SignPKICertWithClassicKey.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def key_usage(self):
        """Gets the key_usage of this SignPKICertWithClassicKey.  # noqa: E501

        key-usage  # noqa: E501

        :return: The key_usage of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._key_usage

    @key_usage.setter
    def key_usage(self, key_usage):
        """Sets the key_usage of this SignPKICertWithClassicKey.

        key-usage  # noqa: E501

        :param key_usage: The key_usage of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._key_usage = key_usage

    @property
    def locality(self):
        """Gets the locality of this SignPKICertWithClassicKey.  # noqa: E501

        A comma-separated list of the locality that will be set in the issued certificate  # noqa: E501

        :return: The locality of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """Sets the locality of this SignPKICertWithClassicKey.

        A comma-separated list of the locality that will be set in the issued certificate  # noqa: E501

        :param locality: The locality of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._locality = locality

    @property
    def organizational_units(self):
        """Gets the organizational_units of this SignPKICertWithClassicKey.  # noqa: E501

        A comma-separated list of organizational units (OU) that will be set in the issued certificate  # noqa: E501

        :return: The organizational_units of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._organizational_units

    @organizational_units.setter
    def organizational_units(self, organizational_units):
        """Sets the organizational_units of this SignPKICertWithClassicKey.

        A comma-separated list of organizational units (OU) that will be set in the issued certificate  # noqa: E501

        :param organizational_units: The organizational_units of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._organizational_units = organizational_units

    @property
    def organizations(self):
        """Gets the organizations of this SignPKICertWithClassicKey.  # noqa: E501

        A comma-separated list of organizations (O) that will be set in the issued certificate  # noqa: E501

        :return: The organizations of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._organizations

    @organizations.setter
    def organizations(self, organizations):
        """Sets the organizations of this SignPKICertWithClassicKey.

        A comma-separated list of organizations (O) that will be set in the issued certificate  # noqa: E501

        :param organizations: The organizations of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._organizations = organizations

    @property
    def postal_code(self):
        """Gets the postal_code of this SignPKICertWithClassicKey.  # noqa: E501

        A comma-separated list of the postal code that will be set in the issued certificate  # noqa: E501

        :return: The postal_code of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this SignPKICertWithClassicKey.

        A comma-separated list of the postal code that will be set in the issued certificate  # noqa: E501

        :param postal_code: The postal_code of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def province(self):
        """Gets the province of this SignPKICertWithClassicKey.  # noqa: E501

        A comma-separated list of the province that will be set in the issued certificate  # noqa: E501

        :return: The province of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._province

    @province.setter
    def province(self, province):
        """Sets the province of this SignPKICertWithClassicKey.

        A comma-separated list of the province that will be set in the issued certificate  # noqa: E501

        :param province: The province of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._province = province

    @property
    def public_key_pem_data(self):
        """Gets the public_key_pem_data of this SignPKICertWithClassicKey.  # noqa: E501

        PublicKey using for signing in a PEM format.  # noqa: E501

        :return: The public_key_pem_data of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._public_key_pem_data

    @public_key_pem_data.setter
    def public_key_pem_data(self, public_key_pem_data):
        """Sets the public_key_pem_data of this SignPKICertWithClassicKey.

        PublicKey using for signing in a PEM format.  # noqa: E501

        :param public_key_pem_data: The public_key_pem_data of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._public_key_pem_data = public_key_pem_data

    @property
    def signing_method(self):
        """Gets the signing_method of this SignPKICertWithClassicKey.  # noqa: E501

        SigningMethod  # noqa: E501

        :return: The signing_method of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._signing_method

    @signing_method.setter
    def signing_method(self, signing_method):
        """Sets the signing_method of this SignPKICertWithClassicKey.

        SigningMethod  # noqa: E501

        :param signing_method: The signing_method of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signing_method is None:  # noqa: E501
            raise ValueError("Invalid value for `signing_method`, must not be `None`")  # noqa: E501

        self._signing_method = signing_method

    @property
    def street_address(self):
        """Gets the street_address of this SignPKICertWithClassicKey.  # noqa: E501

        A comma-separated list of the street address that will be set in the issued certificate  # noqa: E501

        :return: The street_address of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._street_address

    @street_address.setter
    def street_address(self, street_address):
        """Sets the street_address of this SignPKICertWithClassicKey.

        A comma-separated list of the street address that will be set in the issued certificate  # noqa: E501

        :param street_address: The street_address of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._street_address = street_address

    @property
    def token(self):
        """Gets the token of this SignPKICertWithClassicKey.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this SignPKICertWithClassicKey.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def ttl(self):
        """Gets the ttl of this SignPKICertWithClassicKey.  # noqa: E501

        he requested Time To Live for the certificate, in seconds  # noqa: E501

        :return: The ttl of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this SignPKICertWithClassicKey.

        he requested Time To Live for the certificate, in seconds  # noqa: E501

        :param ttl: The ttl of this SignPKICertWithClassicKey.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and ttl is None:  # noqa: E501
            raise ValueError("Invalid value for `ttl`, must not be `None`")  # noqa: E501

        self._ttl = ttl

    @property
    def uid_token(self):
        """Gets the uid_token of this SignPKICertWithClassicKey.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this SignPKICertWithClassicKey.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def uri_sans(self):
        """Gets the uri_sans of this SignPKICertWithClassicKey.  # noqa: E501

        The URI Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :return: The uri_sans of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._uri_sans

    @uri_sans.setter
    def uri_sans(self, uri_sans):
        """Sets the uri_sans of this SignPKICertWithClassicKey.

        The URI Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :param uri_sans: The uri_sans of this SignPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._uri_sans = uri_sans

    @property
    def version(self):
        """Gets the version of this SignPKICertWithClassicKey.  # noqa: E501

        classic key version  # noqa: E501

        :return: The version of this SignPKICertWithClassicKey.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SignPKICertWithClassicKey.

        classic key version  # noqa: E501

        :param version: The version of this SignPKICertWithClassicKey.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignPKICertWithClassicKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SignPKICertWithClassicKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.pki_certificate_issue_details import PKICertificateIssueDetails  # noqa: E501
from akeyless.rest import ApiException

class TestPKICertificateIssueDetails(unittest.TestCase):
    """PKICertificateIssueDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PKICertificateIssueDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.pki_certificate_issue_details.PKICertificateIssueDetails()  # noqa: E501
        if include_optional :
            return PKICertificateIssueDetails(
                allow_any_name = True, 
                allow_subdomains = True, 
                allowed_domains_list = [
                    '0'
                    ], 
                allowed_uri_sans = [
                    '0'
                    ], 
                client_flag = True, 
                code_signing_flag = True, 
                country = [
                    '0'
                    ], 
                enforce_hostnames = True, 
                key_bits = 56, 
                key_type = '0', 
                key_usage_list = [
                    '0'
                    ], 
                locality = [
                    '0'
                    ], 
                not_before_duration = 56, 
                organization_list = [
                    '0'
                    ], 
                organization_unit_list = [
                    '0'
                    ], 
                postal_code = [
                    '0'
                    ], 
                province = [
                    '0'
                    ], 
                require_cn = True, 
                server_flag = True, 
                street_address = [
                    '0'
                    ]
            )
        else :
            return PKICertificateIssueDetails(
        )

    def testPKICertificateIssueDetails(self):
        """Test PKICertificateIssueDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CertificateInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ext_key_usage': 'list[int]',
        'key_usage': 'int',
        'dns_names': 'list[str]',
        'email_addresses': 'list[str]',
        'extensions': 'list[Extension]',
        'ip_addresses': 'list[str]',
        'is_ca': 'bool',
        'issuer': 'Name',
        'issuing_certificate_url': 'list[str]',
        'key_size': 'int',
        'not_after': 'datetime',
        'not_before': 'datetime',
        'ocsp_server': 'list[str]',
        'public_key_algorithm_name': 'str',
        'serial_number': 'str',
        'sha_1_fingerprint': 'str',
        'sha_256_fingerprint': 'str',
        'signature': 'str',
        'signature_algorithm_name': 'str',
        'subject': 'Name',
        'subject_public_key': 'str',
        'uris': 'list[str]',
        'version': 'int'
    }

    attribute_map = {
        'ext_key_usage': 'ExtKeyUsage',
        'key_usage': 'KeyUsage',
        'dns_names': 'dns_names',
        'email_addresses': 'email_addresses',
        'extensions': 'extensions',
        'ip_addresses': 'ip_addresses',
        'is_ca': 'is_ca',
        'issuer': 'issuer',
        'issuing_certificate_url': 'issuing_certificate_url',
        'key_size': 'key_size',
        'not_after': 'not_after',
        'not_before': 'not_before',
        'ocsp_server': 'ocsp_server',
        'public_key_algorithm_name': 'public_key_algorithm_name',
        'serial_number': 'serial_number',
        'sha_1_fingerprint': 'sha_1_fingerprint',
        'sha_256_fingerprint': 'sha_256_fingerprint',
        'signature': 'signature',
        'signature_algorithm_name': 'signature_algorithm_name',
        'subject': 'subject',
        'subject_public_key': 'subject_public_key',
        'uris': 'uris',
        'version': 'version'
    }

    def __init__(self, ext_key_usage=None, key_usage=None, dns_names=None, email_addresses=None, extensions=None, ip_addresses=None, is_ca=None, issuer=None, issuing_certificate_url=None, key_size=None, not_after=None, not_before=None, ocsp_server=None, public_key_algorithm_name=None, serial_number=None, sha_1_fingerprint=None, sha_256_fingerprint=None, signature=None, signature_algorithm_name=None, subject=None, subject_public_key=None, uris=None, version=None, local_vars_configuration=None):  # noqa: E501
        """CertificateInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ext_key_usage = None
        self._key_usage = None
        self._dns_names = None
        self._email_addresses = None
        self._extensions = None
        self._ip_addresses = None
        self._is_ca = None
        self._issuer = None
        self._issuing_certificate_url = None
        self._key_size = None
        self._not_after = None
        self._not_before = None
        self._ocsp_server = None
        self._public_key_algorithm_name = None
        self._serial_number = None
        self._sha_1_fingerprint = None
        self._sha_256_fingerprint = None
        self._signature = None
        self._signature_algorithm_name = None
        self._subject = None
        self._subject_public_key = None
        self._uris = None
        self._version = None
        self.discriminator = None

        if ext_key_usage is not None:
            self.ext_key_usage = ext_key_usage
        if key_usage is not None:
            self.key_usage = key_usage
        if dns_names is not None:
            self.dns_names = dns_names
        if email_addresses is not None:
            self.email_addresses = email_addresses
        if extensions is not None:
            self.extensions = extensions
        if ip_addresses is not None:
            self.ip_addresses = ip_addresses
        if is_ca is not None:
            self.is_ca = is_ca
        if issuer is not None:
            self.issuer = issuer
        if issuing_certificate_url is not None:
            self.issuing_certificate_url = issuing_certificate_url
        if key_size is not None:
            self.key_size = key_size
        if not_after is not None:
            self.not_after = not_after
        if not_before is not None:
            self.not_before = not_before
        if ocsp_server is not None:
            self.ocsp_server = ocsp_server
        if public_key_algorithm_name is not None:
            self.public_key_algorithm_name = public_key_algorithm_name
        if serial_number is not None:
            self.serial_number = serial_number
        if sha_1_fingerprint is not None:
            self.sha_1_fingerprint = sha_1_fingerprint
        if sha_256_fingerprint is not None:
            self.sha_256_fingerprint = sha_256_fingerprint
        if signature is not None:
            self.signature = signature
        if signature_algorithm_name is not None:
            self.signature_algorithm_name = signature_algorithm_name
        if subject is not None:
            self.subject = subject
        if subject_public_key is not None:
            self.subject_public_key = subject_public_key
        if uris is not None:
            self.uris = uris
        if version is not None:
            self.version = version

    @property
    def ext_key_usage(self):
        """Gets the ext_key_usage of this CertificateInfo.  # noqa: E501


        :return: The ext_key_usage of this CertificateInfo.  # noqa: E501
        :rtype: list[int]
        """
        return self._ext_key_usage

    @ext_key_usage.setter
    def ext_key_usage(self, ext_key_usage):
        """Sets the ext_key_usage of this CertificateInfo.


        :param ext_key_usage: The ext_key_usage of this CertificateInfo.  # noqa: E501
        :type: list[int]
        """

        self._ext_key_usage = ext_key_usage

    @property
    def key_usage(self):
        """Gets the key_usage of this CertificateInfo.  # noqa: E501

        KeyUsage represents the set of actions that are valid for a given key. It's a bitmap of the KeyUsage* constants.  # noqa: E501

        :return: The key_usage of this CertificateInfo.  # noqa: E501
        :rtype: int
        """
        return self._key_usage

    @key_usage.setter
    def key_usage(self, key_usage):
        """Sets the key_usage of this CertificateInfo.

        KeyUsage represents the set of actions that are valid for a given key. It's a bitmap of the KeyUsage* constants.  # noqa: E501

        :param key_usage: The key_usage of this CertificateInfo.  # noqa: E501
        :type: int
        """

        self._key_usage = key_usage

    @property
    def dns_names(self):
        """Gets the dns_names of this CertificateInfo.  # noqa: E501


        :return: The dns_names of this CertificateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._dns_names

    @dns_names.setter
    def dns_names(self, dns_names):
        """Sets the dns_names of this CertificateInfo.


        :param dns_names: The dns_names of this CertificateInfo.  # noqa: E501
        :type: list[str]
        """

        self._dns_names = dns_names

    @property
    def email_addresses(self):
        """Gets the email_addresses of this CertificateInfo.  # noqa: E501


        :return: The email_addresses of this CertificateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._email_addresses

    @email_addresses.setter
    def email_addresses(self, email_addresses):
        """Sets the email_addresses of this CertificateInfo.


        :param email_addresses: The email_addresses of this CertificateInfo.  # noqa: E501
        :type: list[str]
        """

        self._email_addresses = email_addresses

    @property
    def extensions(self):
        """Gets the extensions of this CertificateInfo.  # noqa: E501


        :return: The extensions of this CertificateInfo.  # noqa: E501
        :rtype: list[Extension]
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this CertificateInfo.


        :param extensions: The extensions of this CertificateInfo.  # noqa: E501
        :type: list[Extension]
        """

        self._extensions = extensions

    @property
    def ip_addresses(self):
        """Gets the ip_addresses of this CertificateInfo.  # noqa: E501


        :return: The ip_addresses of this CertificateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._ip_addresses

    @ip_addresses.setter
    def ip_addresses(self, ip_addresses):
        """Sets the ip_addresses of this CertificateInfo.


        :param ip_addresses: The ip_addresses of this CertificateInfo.  # noqa: E501
        :type: list[str]
        """

        self._ip_addresses = ip_addresses

    @property
    def is_ca(self):
        """Gets the is_ca of this CertificateInfo.  # noqa: E501


        :return: The is_ca of this CertificateInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_ca

    @is_ca.setter
    def is_ca(self, is_ca):
        """Sets the is_ca of this CertificateInfo.


        :param is_ca: The is_ca of this CertificateInfo.  # noqa: E501
        :type: bool
        """

        self._is_ca = is_ca

    @property
    def issuer(self):
        """Gets the issuer of this CertificateInfo.  # noqa: E501


        :return: The issuer of this CertificateInfo.  # noqa: E501
        :rtype: Name
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this CertificateInfo.


        :param issuer: The issuer of this CertificateInfo.  # noqa: E501
        :type: Name
        """

        self._issuer = issuer

    @property
    def issuing_certificate_url(self):
        """Gets the issuing_certificate_url of this CertificateInfo.  # noqa: E501


        :return: The issuing_certificate_url of this CertificateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._issuing_certificate_url

    @issuing_certificate_url.setter
    def issuing_certificate_url(self, issuing_certificate_url):
        """Sets the issuing_certificate_url of this CertificateInfo.


        :param issuing_certificate_url: The issuing_certificate_url of this CertificateInfo.  # noqa: E501
        :type: list[str]
        """

        self._issuing_certificate_url = issuing_certificate_url

    @property
    def key_size(self):
        """Gets the key_size of this CertificateInfo.  # noqa: E501


        :return: The key_size of this CertificateInfo.  # noqa: E501
        :rtype: int
        """
        return self._key_size

    @key_size.setter
    def key_size(self, key_size):
        """Sets the key_size of this CertificateInfo.


        :param key_size: The key_size of this CertificateInfo.  # noqa: E501
        :type: int
        """

        self._key_size = key_size

    @property
    def not_after(self):
        """Gets the not_after of this CertificateInfo.  # noqa: E501


        :return: The not_after of this CertificateInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._not_after

    @not_after.setter
    def not_after(self, not_after):
        """Sets the not_after of this CertificateInfo.


        :param not_after: The not_after of this CertificateInfo.  # noqa: E501
        :type: datetime
        """

        self._not_after = not_after

    @property
    def not_before(self):
        """Gets the not_before of this CertificateInfo.  # noqa: E501


        :return: The not_before of this CertificateInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._not_before

    @not_before.setter
    def not_before(self, not_before):
        """Sets the not_before of this CertificateInfo.


        :param not_before: The not_before of this CertificateInfo.  # noqa: E501
        :type: datetime
        """

        self._not_before = not_before

    @property
    def ocsp_server(self):
        """Gets the ocsp_server of this CertificateInfo.  # noqa: E501


        :return: The ocsp_server of this CertificateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._ocsp_server

    @ocsp_server.setter
    def ocsp_server(self, ocsp_server):
        """Sets the ocsp_server of this CertificateInfo.


        :param ocsp_server: The ocsp_server of this CertificateInfo.  # noqa: E501
        :type: list[str]
        """

        self._ocsp_server = ocsp_server

    @property
    def public_key_algorithm_name(self):
        """Gets the public_key_algorithm_name of this CertificateInfo.  # noqa: E501


        :return: The public_key_algorithm_name of this CertificateInfo.  # noqa: E501
        :rtype: str
        """
        return self._public_key_algorithm_name

    @public_key_algorithm_name.setter
    def public_key_algorithm_name(self, public_key_algorithm_name):
        """Sets the public_key_algorithm_name of this CertificateInfo.


        :param public_key_algorithm_name: The public_key_algorithm_name of this CertificateInfo.  # noqa: E501
        :type: str
        """

        self._public_key_algorithm_name = public_key_algorithm_name

    @property
    def serial_number(self):
        """Gets the serial_number of this CertificateInfo.  # noqa: E501


        :return: The serial_number of this CertificateInfo.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this CertificateInfo.


        :param serial_number: The serial_number of this CertificateInfo.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def sha_1_fingerprint(self):
        """Gets the sha_1_fingerprint of this CertificateInfo.  # noqa: E501


        :return: The sha_1_fingerprint of this CertificateInfo.  # noqa: E501
        :rtype: str
        """
        return self._sha_1_fingerprint

    @sha_1_fingerprint.setter
    def sha_1_fingerprint(self, sha_1_fingerprint):
        """Sets the sha_1_fingerprint of this CertificateInfo.


        :param sha_1_fingerprint: The sha_1_fingerprint of this CertificateInfo.  # noqa: E501
        :type: str
        """

        self._sha_1_fingerprint = sha_1_fingerprint

    @property
    def sha_256_fingerprint(self):
        """Gets the sha_256_fingerprint of this CertificateInfo.  # noqa: E501


        :return: The sha_256_fingerprint of this CertificateInfo.  # noqa: E501
        :rtype: str
        """
        return self._sha_256_fingerprint

    @sha_256_fingerprint.setter
    def sha_256_fingerprint(self, sha_256_fingerprint):
        """Sets the sha_256_fingerprint of this CertificateInfo.


        :param sha_256_fingerprint: The sha_256_fingerprint of this CertificateInfo.  # noqa: E501
        :type: str
        """

        self._sha_256_fingerprint = sha_256_fingerprint

    @property
    def signature(self):
        """Gets the signature of this CertificateInfo.  # noqa: E501


        :return: The signature of this CertificateInfo.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this CertificateInfo.


        :param signature: The signature of this CertificateInfo.  # noqa: E501
        :type: str
        """

        self._signature = signature

    @property
    def signature_algorithm_name(self):
        """Gets the signature_algorithm_name of this CertificateInfo.  # noqa: E501


        :return: The signature_algorithm_name of this CertificateInfo.  # noqa: E501
        :rtype: str
        """
        return self._signature_algorithm_name

    @signature_algorithm_name.setter
    def signature_algorithm_name(self, signature_algorithm_name):
        """Sets the signature_algorithm_name of this CertificateInfo.


        :param signature_algorithm_name: The signature_algorithm_name of this CertificateInfo.  # noqa: E501
        :type: str
        """

        self._signature_algorithm_name = signature_algorithm_name

    @property
    def subject(self):
        """Gets the subject of this CertificateInfo.  # noqa: E501


        :return: The subject of this CertificateInfo.  # noqa: E501
        :rtype: Name
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this CertificateInfo.


        :param subject: The subject of this CertificateInfo.  # noqa: E501
        :type: Name
        """

        self._subject = subject

    @property
    def subject_public_key(self):
        """Gets the subject_public_key of this CertificateInfo.  # noqa: E501


        :return: The subject_public_key of this CertificateInfo.  # noqa: E501
        :rtype: str
        """
        return self._subject_public_key

    @subject_public_key.setter
    def subject_public_key(self, subject_public_key):
        """Sets the subject_public_key of this CertificateInfo.


        :param subject_public_key: The subject_public_key of this CertificateInfo.  # noqa: E501
        :type: str
        """

        self._subject_public_key = subject_public_key

    @property
    def uris(self):
        """Gets the uris of this CertificateInfo.  # noqa: E501


        :return: The uris of this CertificateInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._uris

    @uris.setter
    def uris(self, uris):
        """Sets the uris of this CertificateInfo.


        :param uris: The uris of this CertificateInfo.  # noqa: E501
        :type: list[str]
        """

        self._uris = uris

    @property
    def version(self):
        """Gets the version of this CertificateInfo.  # noqa: E501


        :return: The version of this CertificateInfo.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CertificateInfo.


        :param version: The version of this CertificateInfo.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertificateInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CertificateInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.tokenizer_info import TokenizerInfo  # noqa: E501
from akeyless.rest import ApiException

class TestTokenizerInfo(unittest.TestCase):
    """TokenizerInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TokenizerInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.tokenizer_info.TokenizerInfo()  # noqa: E501
        if include_optional :
            return TokenizerInfo(
                vaultless_tokenizer_info = akeyless.models.vaultless_tokenizer_info.VaultlessTokenizerInfo(
                    email_tokenizer_info = akeyless.models.email_tokenizer_info.EmailTokenizerInfo(
                        domain_suffix_length = 56, 
                        fixed_domain_suffix = '0', 
                        keep_prefix_length = 56, ), 
                    key_name = '0', 
                    regexp_tokenizer_info = akeyless.models.regexp_tokenizer_info.RegexpTokenizerInfo(
                        alphabet = '0', 
                        decryption_template = '0', 
                        encryption_template = '0', 
                        pattern = '0', ), 
                    template_type = '0', 
                    tweak = [
                        56
                        ], 
                    tweak_type = '0', )
            )
        else :
            return TokenizerInfo(
        )

    def testTokenizerInfo(self):
        """Test TokenizerInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.item_general_info import ItemGeneralInfo  # noqa: E501
from akeyless.rest import ApiException

class TestItemGeneralInfo(unittest.TestCase):
    """ItemGeneralInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ItemGeneralInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.item_general_info.ItemGeneralInfo()  # noqa: E501
        if include_optional :
            return ItemGeneralInfo(
                cert_issue_details = akeyless.models.certificate_issue_info_defines_certificate_issuer_info/.CertificateIssueInfo defines Certificate Issuer info.(
                    cert_issuer_type = '0', 
                    max_ttl = 56, 
                    pki_cert_issuer_details = akeyless.models.pki_certificate_issue_details_defines_pki_certificate_details/.PKICertificateIssueDetails defines PKI certificate details.(
                        allow_any_name = True, 
                        allow_subdomains = True, 
                        allowed_domains_list = [
                            '0'
                            ], 
                        allowed_uri_sans = [
                            '0'
                            ], 
                        client_flag = True, 
                        code_signing_flag = True, 
                        country = [
                            '0'
                            ], 
                        enforce_hostnames = True, 
                        key_bits = 56, 
                        key_type = '0', 
                        key_usage_list = [
                            '0'
                            ], 
                        locality = [
                            '0'
                            ], 
                        not_before_duration = 56, 
                        organization_list = [
                            '0'
                            ], 
                        organization_unit_list = [
                            '0'
                            ], 
                        postal_code = [
                            '0'
                            ], 
                        province = [
                            '0'
                            ], 
                        require_cn = True, 
                        server_flag = True, 
                        street_address = [
                            '0'
                            ], ), 
                    ssh_cert_issuer_details = akeyless.models.ssh_certificate_issue_details_defines_ssh_certificate_details/.SSHCertificateIssueDetails defines SSH certificate details.(
                        allowed_domains = [
                            '0'
                            ], 
                        allowed_user_key_lengths = {
                            'key' : 56
                            }, 
                        allowed_users = [
                            '0'
                            ], 
                        cert_type = 56, 
                        critical_options = {
                            'key' : '0'
                            }, 
                        extensions = {
                            'key' : '0'
                            }, 
                        principals = [
                            '0'
                            ], 
                        static_key_id = '0', ), ), 
                dynamic_secret_producer_details = akeyless.models.dynamic_secret_producer_info.DynamicSecretProducerInfo(
                    producer_status = '0', 
                    producer_type = '0', )
            )
        else :
            return ItemGeneralInfo(
        )

    def testItemGeneralInfo(self):
        """Test ItemGeneralInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



import os
import time
import unittest

import akeyless
from akeyless.rest import ApiException


class TestSDK(unittest.TestCase):
    def setUp(self):
        host = os.getenv('AKEYLESS_TEST_HOST')
        configuration = akeyless.Configuration(host=host)

        with akeyless.ApiClient(configuration) as api_client:
            self.api = akeyless.V2Api(api_client)

        self.access_id = os.getenv('AKEYLESS_TEST_ACCESS_ID')
        self.access_key = os.getenv('AKEYLESS_TEST_ACCESS_KEY')

        if not self.access_id or not self.access_key:
            self.fail("missing access credentials")

    def tearDown(self):
        pass

    def test_roles(self):
        t = time.time()

        body = akeyless.Auth(access_id=self.access_id, access_key=self.access_key)
        res = self.api.auth(body)
        token = res.token

        role_name = 'pyrole-{}'.format(t)
        body = akeyless.CreateRole(token=token, name=role_name)
        self.api.create_role(body)

        body = akeyless.SetRoleRule(capability=['list', 'read'], path='/pytest-item/*',
                role_name=role_name, token=token)

        for rule_type in ['role-rule', 'item-rule', 'auth-method-rule']:
            body.rule_type = rule_type
            self.api.set_role_rule(body)

        am_name = 'pyam-{}'.format(t)
        body = akeyless.CreateAuthMethod(name=am_name, token=token)
        res = self.api.create_auth_method(body)

        amID = res.access_id
        amKey = res.access_key

        body = akeyless.AssocRoleAuthMethod(am_name=am_name, role_name=role_name,
                token=token)
        self.api.assoc_role_auth_method(body)

        secret_name = '/pytest-item/secret-{}'.format(t)
        secret_value = 'secret-{}'.format(t)

        body = akeyless.CreateSecret(name=secret_name, value=secret_value, token=token)
        self.api.create_secret(body)

        body = akeyless.Auth(access_id=amID, access_key=amKey)
        res = self.api.auth(body)
        amToken = res.token

        body = akeyless.GetSecretValue(names=[secret_name], token=token)
        res = self.api.get_secret_value(body)
        self.assertEqual(res[secret_name], secret_value)

        body = akeyless.ListItems(token=amToken)
        res = self.api.list_items(body)
        self.assertTrue(len(res.items) > 0)

        for item in res.items:
            if item.item_name.startswith('/pytest-item/'):
                body = akeyless.DeleteItem(delete_immediately=True,
                        delete_in_days=-1, name=item.item_name, token=token)
                self.api.delete_item(body)

        body = akeyless.ListAuthMethods(token=token)
        res = self.api.list_auth_methods(body)

        for am in res.auth_methods:
            if am.auth_method_name.startswith('pyam'):
                body = akeyless.DeleteAuthMethod(token=token,
                        name=am.auth_method_name)
                self.api.delete_auth_method(body)

        body = akeyless.ListRoles(token=token)
        res = self.api.list_roles(body)

        for role in res.roles:
            if role.role_name.startswith('pyrole'):
                body = akeyless.DeleteRole(token=token,
                        name=role.role_name)
                self.api.delete_role(body)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UIDTokenDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'children': 'dict(str, UIDTokenDetails)',
        'comment': 'str',
        'deny_inheritance': 'bool',
        'deny_rotate': 'bool',
        'depth': 'int',
        'expired_date': 'str',
        'id': 'str',
        'last_rotate': 'str',
        'revoked': 'bool',
        'ttl': 'int'
    }

    attribute_map = {
        'children': 'children',
        'comment': 'comment',
        'deny_inheritance': 'deny_inheritance',
        'deny_rotate': 'deny_rotate',
        'depth': 'depth',
        'expired_date': 'expired_date',
        'id': 'id',
        'last_rotate': 'last_rotate',
        'revoked': 'revoked',
        'ttl': 'ttl'
    }

    def __init__(self, children=None, comment=None, deny_inheritance=None, deny_rotate=None, depth=None, expired_date=None, id=None, last_rotate=None, revoked=None, ttl=None, local_vars_configuration=None):  # noqa: E501
        """UIDTokenDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._children = None
        self._comment = None
        self._deny_inheritance = None
        self._deny_rotate = None
        self._depth = None
        self._expired_date = None
        self._id = None
        self._last_rotate = None
        self._revoked = None
        self._ttl = None
        self.discriminator = None

        if children is not None:
            self.children = children
        if comment is not None:
            self.comment = comment
        if deny_inheritance is not None:
            self.deny_inheritance = deny_inheritance
        if deny_rotate is not None:
            self.deny_rotate = deny_rotate
        if depth is not None:
            self.depth = depth
        if expired_date is not None:
            self.expired_date = expired_date
        if id is not None:
            self.id = id
        if last_rotate is not None:
            self.last_rotate = last_rotate
        if revoked is not None:
            self.revoked = revoked
        if ttl is not None:
            self.ttl = ttl

    @property
    def children(self):
        """Gets the children of this UIDTokenDetails.  # noqa: E501


        :return: The children of this UIDTokenDetails.  # noqa: E501
        :rtype: dict(str, UIDTokenDetails)
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this UIDTokenDetails.


        :param children: The children of this UIDTokenDetails.  # noqa: E501
        :type: dict(str, UIDTokenDetails)
        """

        self._children = children

    @property
    def comment(self):
        """Gets the comment of this UIDTokenDetails.  # noqa: E501


        :return: The comment of this UIDTokenDetails.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UIDTokenDetails.


        :param comment: The comment of this UIDTokenDetails.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def deny_inheritance(self):
        """Gets the deny_inheritance of this UIDTokenDetails.  # noqa: E501


        :return: The deny_inheritance of this UIDTokenDetails.  # noqa: E501
        :rtype: bool
        """
        return self._deny_inheritance

    @deny_inheritance.setter
    def deny_inheritance(self, deny_inheritance):
        """Sets the deny_inheritance of this UIDTokenDetails.


        :param deny_inheritance: The deny_inheritance of this UIDTokenDetails.  # noqa: E501
        :type: bool
        """

        self._deny_inheritance = deny_inheritance

    @property
    def deny_rotate(self):
        """Gets the deny_rotate of this UIDTokenDetails.  # noqa: E501


        :return: The deny_rotate of this UIDTokenDetails.  # noqa: E501
        :rtype: bool
        """
        return self._deny_rotate

    @deny_rotate.setter
    def deny_rotate(self, deny_rotate):
        """Sets the deny_rotate of this UIDTokenDetails.


        :param deny_rotate: The deny_rotate of this UIDTokenDetails.  # noqa: E501
        :type: bool
        """

        self._deny_rotate = deny_rotate

    @property
    def depth(self):
        """Gets the depth of this UIDTokenDetails.  # noqa: E501


        :return: The depth of this UIDTokenDetails.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this UIDTokenDetails.


        :param depth: The depth of this UIDTokenDetails.  # noqa: E501
        :type: int
        """

        self._depth = depth

    @property
    def expired_date(self):
        """Gets the expired_date of this UIDTokenDetails.  # noqa: E501


        :return: The expired_date of this UIDTokenDetails.  # noqa: E501
        :rtype: str
        """
        return self._expired_date

    @expired_date.setter
    def expired_date(self, expired_date):
        """Sets the expired_date of this UIDTokenDetails.


        :param expired_date: The expired_date of this UIDTokenDetails.  # noqa: E501
        :type: str
        """

        self._expired_date = expired_date

    @property
    def id(self):
        """Gets the id of this UIDTokenDetails.  # noqa: E501


        :return: The id of this UIDTokenDetails.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UIDTokenDetails.


        :param id: The id of this UIDTokenDetails.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def last_rotate(self):
        """Gets the last_rotate of this UIDTokenDetails.  # noqa: E501


        :return: The last_rotate of this UIDTokenDetails.  # noqa: E501
        :rtype: str
        """
        return self._last_rotate

    @last_rotate.setter
    def last_rotate(self, last_rotate):
        """Sets the last_rotate of this UIDTokenDetails.


        :param last_rotate: The last_rotate of this UIDTokenDetails.  # noqa: E501
        :type: str
        """

        self._last_rotate = last_rotate

    @property
    def revoked(self):
        """Gets the revoked of this UIDTokenDetails.  # noqa: E501


        :return: The revoked of this UIDTokenDetails.  # noqa: E501
        :rtype: bool
        """
        return self._revoked

    @revoked.setter
    def revoked(self, revoked):
        """Sets the revoked of this UIDTokenDetails.


        :param revoked: The revoked of this UIDTokenDetails.  # noqa: E501
        :type: bool
        """

        self._revoked = revoked

    @property
    def ttl(self):
        """Gets the ttl of this UIDTokenDetails.  # noqa: E501


        :return: The ttl of this UIDTokenDetails.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this UIDTokenDetails.


        :param ttl: The ttl of this UIDTokenDetails.  # noqa: E501
        :type: int
        """

        self._ttl = ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UIDTokenDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UIDTokenDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.sign_pki_cert_with_classic_key import SignPKICertWithClassicKey  # noqa: E501
from akeyless.rest import ApiException

class TestSignPKICertWithClassicKey(unittest.TestCase):
    """SignPKICertWithClassicKey unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SignPKICertWithClassicKey
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.sign_pki_cert_with_classic_key.SignPKICertWithClassicKey()  # noqa: E501
        if include_optional :
            return SignPKICertWithClassicKey(
                common_name = '0', 
                country = '0', 
                display_id = '0', 
                dns_names = '0', 
                key_usage = 'DigitalSignature,KeyAgreement,KeyEncipherment', 
                locality = '0', 
                organizational_units = '0', 
                organizations = '0', 
                password = '0', 
                postal_code = '0', 
                province = '0', 
                public_key_pem_data = '0', 
                signing_method = '0', 
                street_address = '0', 
                token = '0', 
                ttl = 56, 
                uid_token = '0', 
                uri_sans = '0', 
                username = '0', 
                version = 56
            )
        else :
            return SignPKICertWithClassicKey(
                display_id = '0',
                signing_method = '0',
                ttl = 56,
                version = 56,
        )

    def testSignPKICertWithClassicKey(self):
        """Test SignPKICertWithClassicKey"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class KubernetesAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alg': 'str',
        'audience': 'str',
        'bound_namespaces': 'list[str]',
        'bound_pod_names': 'list[str]',
        'bound_service_account_names': 'list[str]',
        'gen_key_pair': 'str',
        'pub_key': 'str'
    }

    attribute_map = {
        'alg': 'alg',
        'audience': 'audience',
        'bound_namespaces': 'bound_namespaces',
        'bound_pod_names': 'bound_pod_names',
        'bound_service_account_names': 'bound_service_account_names',
        'gen_key_pair': 'gen_key_pair',
        'pub_key': 'pub_key'
    }

    def __init__(self, alg=None, audience=None, bound_namespaces=None, bound_pod_names=None, bound_service_account_names=None, gen_key_pair=None, pub_key=None, local_vars_configuration=None):  # noqa: E501
        """KubernetesAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alg = None
        self._audience = None
        self._bound_namespaces = None
        self._bound_pod_names = None
        self._bound_service_account_names = None
        self._gen_key_pair = None
        self._pub_key = None
        self.discriminator = None

        if alg is not None:
            self.alg = alg
        if audience is not None:
            self.audience = audience
        if bound_namespaces is not None:
            self.bound_namespaces = bound_namespaces
        if bound_pod_names is not None:
            self.bound_pod_names = bound_pod_names
        if bound_service_account_names is not None:
            self.bound_service_account_names = bound_service_account_names
        if gen_key_pair is not None:
            self.gen_key_pair = gen_key_pair
        if pub_key is not None:
            self.pub_key = pub_key

    @property
    def alg(self):
        """Gets the alg of this KubernetesAccessRules.  # noqa: E501


        :return: The alg of this KubernetesAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._alg

    @alg.setter
    def alg(self, alg):
        """Sets the alg of this KubernetesAccessRules.


        :param alg: The alg of this KubernetesAccessRules.  # noqa: E501
        :type: str
        """

        self._alg = alg

    @property
    def audience(self):
        """Gets the audience of this KubernetesAccessRules.  # noqa: E501

        Audience is an optional Kubernetes jwt claim to verify  # noqa: E501

        :return: The audience of this KubernetesAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this KubernetesAccessRules.

        Audience is an optional Kubernetes jwt claim to verify  # noqa: E501

        :param audience: The audience of this KubernetesAccessRules.  # noqa: E501
        :type: str
        """

        self._audience = audience

    @property
    def bound_namespaces(self):
        """Gets the bound_namespaces of this KubernetesAccessRules.  # noqa: E501

        A list of namespaces that the authentication is restricted to.  # noqa: E501

        :return: The bound_namespaces of this KubernetesAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_namespaces

    @bound_namespaces.setter
    def bound_namespaces(self, bound_namespaces):
        """Sets the bound_namespaces of this KubernetesAccessRules.

        A list of namespaces that the authentication is restricted to.  # noqa: E501

        :param bound_namespaces: The bound_namespaces of this KubernetesAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_namespaces = bound_namespaces

    @property
    def bound_pod_names(self):
        """Gets the bound_pod_names of this KubernetesAccessRules.  # noqa: E501

        A list of pods names that the authentication is restricted to.  # noqa: E501

        :return: The bound_pod_names of this KubernetesAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_pod_names

    @bound_pod_names.setter
    def bound_pod_names(self, bound_pod_names):
        """Sets the bound_pod_names of this KubernetesAccessRules.

        A list of pods names that the authentication is restricted to.  # noqa: E501

        :param bound_pod_names: The bound_pod_names of this KubernetesAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_pod_names = bound_pod_names

    @property
    def bound_service_account_names(self):
        """Gets the bound_service_account_names of this KubernetesAccessRules.  # noqa: E501

        A list of service account names that the authentication is restricted to.  # noqa: E501

        :return: The bound_service_account_names of this KubernetesAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_service_account_names

    @bound_service_account_names.setter
    def bound_service_account_names(self, bound_service_account_names):
        """Sets the bound_service_account_names of this KubernetesAccessRules.

        A list of service account names that the authentication is restricted to.  # noqa: E501

        :param bound_service_account_names: The bound_service_account_names of this KubernetesAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_service_account_names = bound_service_account_names

    @property
    def gen_key_pair(self):
        """Gets the gen_key_pair of this KubernetesAccessRules.  # noqa: E501

        Generate public/private key (the private key is required for the K8S Auth Config in the Akeyless Gateway)  # noqa: E501

        :return: The gen_key_pair of this KubernetesAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._gen_key_pair

    @gen_key_pair.setter
    def gen_key_pair(self, gen_key_pair):
        """Sets the gen_key_pair of this KubernetesAccessRules.

        Generate public/private key (the private key is required for the K8S Auth Config in the Akeyless Gateway)  # noqa: E501

        :param gen_key_pair: The gen_key_pair of this KubernetesAccessRules.  # noqa: E501
        :type: str
        """

        self._gen_key_pair = gen_key_pair

    @property
    def pub_key(self):
        """Gets the pub_key of this KubernetesAccessRules.  # noqa: E501

        The public key value of the Kubernetes auth method configuration in the Akeyless Gateway.  # noqa: E501

        :return: The pub_key of this KubernetesAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._pub_key

    @pub_key.setter
    def pub_key(self, pub_key):
        """Sets the pub_key of this KubernetesAccessRules.

        The public key value of the Kubernetes auth method configuration in the Akeyless Gateway.  # noqa: E501

        :param pub_key: The pub_key of this KubernetesAccessRules.  # noqa: E501
        :type: str
        """

        self._pub_key = pub_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KubernetesAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KubernetesAccessRules):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.noti_forwarder import NotiForwarder  # noqa: E501
from akeyless.rest import ApiException

class TestNotiForwarder(unittest.TestCase):
    """NotiForwarder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NotiForwarder
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.noti_forwarder.NotiForwarder()  # noqa: E501
        if include_optional :
            return NotiForwarder(
                client_permissions = [
                    '0'
                    ], 
                comment = '0', 
                creation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                endpoint = '0', 
                event_types = [
                    '0'
                    ], 
                gateway_cluster_id = 56, 
                is_enabled = True, 
                last_version = 56, 
                modification_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                noti_forwarder_id = 56, 
                noti_forwarder_name = '0', 
                noti_forwarder_type = '0', 
                noti_forwarder_versions = [
                    akeyless.models.item_version_describes_an_item_version_in_akeyless/.ItemVersion describes an item version in AKEYLESS.(
                        access_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        creation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer_fragment_id = '0', 
                        deletion_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        item_version_state = '0', 
                        modification_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        protection_key_name = '0', 
                        version = 56, 
                        with_customer_fragment = True, )
                    ], 
                paths = [
                    '0'
                    ], 
                protection_key = '0', 
                runner_type = '0', 
                timespan_in_seconds = 56, 
                to_emails = [
                    akeyless.models.email_entry.EmailEntry(
                        to_email = '0', 
                        to_name = '0', )
                    ], 
                username = '0', 
                with_customer_fragment = True
            )
        else :
            return NotiForwarder(
        )

    def testNotiForwarder(self):
        """Test NotiForwarder"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
